




<?php
require_once('config/app/Query.php');

class CategoriaModel extends Query {
    private $id, $caja, $estado, $nombre;
    public function __construct() {
        parent::__construct();
    }

    public function getCategoria() {
        $sql = "SELECT * FROM categorias";
        $data = $this->selectAll($sql);
        return $data;
       

    }
    public function registrarCategoria(string $nombre,){
        $this->nombre = $nombre;
        $verificar ="SELECT * FROM categorias WHERE nombre = '$this->nombre'";
        $existe = $this->select($verificar);
        if (empty($existe)) {
         $sql = "INSERT INTO categorias (nombre) VALUES (?)";

        $datos = array($this->nombre,);
        $data = $this->save($sql, $datos);
        if ($data == 1) {
            $res = "ok";
        } else {
            $res = "error";   
        }
       
        }else {
            $res ="existe";
        }
        return $res;
    }



    public function registrar_tipo_pago(string $nombre,){
        $this->nombre = $nombre;
        $verificar ="SELECT * FROM tipo_ventas WHERE tipo = '$this->nombre'";
        $existe = $this->select($verificar);
        if (empty($existe)) {
         $sql = "INSERT INTO tipo_ventas (tipo) VALUES (?)";

        $datos = array($this->nombre,);
        $data = $this->save($sql, $datos);
        if ($data == 1) {
            $res = "ok";
        } else {
            $res = "error";   
        }
       
        }else {
            $res ="existe";
        }
        return $res;
    }

    public function consultar_datos_tipo_compras($id){
        $sql = "SELECT * FROM tipo_ventas where id = $id";
        $data = $this->select($sql);
        return $data;
    }





    public function modificarCategoria(string $nombre,int $id){
        $this->nombre = $nombre;
        $this->id = $id;
        
        $sql = "UPDATE categorias SET nombre = ? WHERE id = ?";

        $datos = array($this->nombre, $this->id,);
        $data = $this->save($sql, $datos);
        if ($data == 1) {
            $res = "modificado";
        } else {
            $res = "error";   
        }
        return $res;
    }

    public function modificar_tipo_ventas(string $nombre,int $id){
        $this->nombre = $nombre;
        $this->id = $id;
        
        $sql = "UPDATE tipo_ventas SET tipo = ? WHERE id = ?";

        $datos = array($this->nombre, $this->id,);
        $data = $this->save($sql, $datos);
        if ($data == 1) {
            $res = "modificado";
        } else {
            $res = "error";   
        }
        return $res;
    }

    
 

        public function editarCategoria(int $id)
    {
        $sql = "SELECT * FROM categorias WHERE id=$id";
        $data = $this->select($sql);
        return $data;
    }


    function accionCategoria(int $estado, int $id){
        $this->id = $id;
        $this->estado = $estado;
        $sql = "UPDATE categorias SET estado = ? WHERE id = ?";

        $datos = array($this->estado, $this->id);
        $data = $this->save($sql, $datos);
        return $data;

    }

    public function verificarPermiso(int $id_user, string $nombre) {
        $sql = "SELECT p.id, p.permiso, d.id, d.id_usuario, d.id_permiso FROM permisos p INNER JOIN detalle_permisos d ON p.id = d.id_permiso WHERE d.id_usuario = $id_user AND p.permiso = '$nombre'";
        $data = $this->selectAll($sql);
        return $data;
        
    }

    public function consultar_formas_de_ventas(){
        $sql = "SELECT * FROM tipo_ventas WHERE estado = 1";
        $data = $this->selectAll($sql);
        return $data;
    }



}








?>
