<?php
require_once('./config/app/views.php');
require_once('./config/app/controller.php');
require_once('./models/Categoriamodel.php');

class Categoria extends controller
{       //INICIO DE SSECIO
    public function __construct()
    {
        SESSION_START();
        if (empty($_SESSION ['activo'])) {
           header("location:".base_url);
        }
        //INICIO DE SSECION 
  $this->model = new Categoriamodel();
        parent::__construct();
    }

    public function index()
    {
        $id_user = (int)$_SESSION['id_usuario'];
        $verificar = $this->model->verificarPermiso($id_user, 'categorias');
        if (!empty($verificar) || $id_user == 1 ) {  
            $this->views->getviews($this, "index");
        } else {
            header('Location: ' . base_url . 'errors/permisos');

        }
       
        
    }

    public function listar()
    {
        $data = $this->model->getCategoria();
        for ($i = 0; $i < count($data); $i++) {
            if ($data[$i]['estado'] == 1) {
                $data[$i]['estado'] = '<span class="badge badge-success">activo</span>';
                $data[$i]['acciones'] = 
                '<div>
                <button class="btn btn-primary" type="button" onclick="btnEditarCategoria(' . $data[$i]['id'] . ');"><i class="fas fa-edit"></i></button>
                <button class="btn btn-danger" type="button" onclick="EliminarCategoria(' . $data[$i]['id'] . ');"><i class="fas fa-trash-alt"></i></button>
                </div>';
            } else {
                $data[$i]['estado'] = '<span class="badge badge-danger">suspendido</span>';
                $data[$i]['acciones'] = '<div>
             
                <button class="btn btn-success" type="button" onclick="btnReningresarCategoria(' . $data[$i]['id'] . ');">Activar</button>
                </div>';
            }
           
        }
        echo json_encode($data, JSON_UNESCAPED_UNICODE);
        die();
    }
    public function forma_de_ventas(){
        $data = $this->model->consultar_formas_de_ventas();
        for ($i = 0; $i < count($data); $i++) {
            if ($data[$i]['estado'] == 1) {
                $data[$i]['estado'] = '<span class="badge badge-success">activo</span>';
                $data[$i]['acciones'] = 
                '<div>
                <button class="btn btn-primary" type="button" onclick="editar_forma_de_pago(' . $data[$i]['id'] . ');"><i class="fas fa-edit"></i></button>
                <button class="btn btn-danger" type="button" onclick="eliminar_formas_de_pago(' . $data[$i]['id'] . ');"><i class="fas fa-trash-alt"></i></button>
                </div>';
            } else {
                $data[$i]['estado'] = '<span class="badge badge-danger">suspendido</span>';
                $data[$i]['acciones'] = '<div>
             
                <button class="btn btn-success" type="button" onclick="btnReningresarCategoria(' . $data[$i]['id'] . ');">Activar</button>
                </div>';
            }
           
        }
        echo json_encode($data, JSON_UNESCAPED_UNICODE);
        die();
    }


    function corregir_tipo_pago($id){
        $data = $this->model->consultar_datos_tipo_compras($id);
        echo json_encode($data, JSON_UNESCAPED_UNICODE);
        exit;
    }
    




    public function registrar()
    {
       
        $nombre = $_POST['nombre'];
        $id = $_POST['id'];
        if (empty($nombre)) {
            $smg = "todos los campos son obligatorios";
        } else {
            if ($id == "") {

                    $data = $this->model->registrarCategoria($nombre);
                    if ($data == "ok") {
                        $smg = "si";
                    } elseif ($data == "existe") {
                        $smg = "el dni ya existe";
                    } else {
                        $smg = "error al registrar el usuario";
                    }
                
            } else {
                $data = $this->model->modificarCategoria($nombre, $id);
                if ($data == "modificado") {
                    $smg = "modificado";
                } else {
                    $smg = "error al modificar el cliente";
                }
            }
        }
        echo json_encode($smg, JSON_UNESCAPED_UNICODE);
        die();
    }



    public function registrar_formas_de_ventas()
    {
       
        $nombre = $_POST['nombre_tipo_venta'];
        $id = $_POST['id_tipo_pago'];
        if (empty($nombre)) {
            $smg = "todos los campos son obligatorios";
        } else {
            if ($id == "") {
                    $data = $this->model->registrar_tipo_pago($nombre);
                    if ($data == "ok") {
                        $smg = "si";
                    } elseif ($data == "existe") {
                        $smg = "el tipo de venta existe";
                    } else {
                        $smg = "error al registrar el usuario";
                    }
                
            } else {
                $data = $this->model->modificar_tipo_ventas($nombre, $id);
                if ($data == "modificado") {
                    $smg = "modificado";
                } else {
                    $smg = "error al modificar el cliente";
                }
            }
        }
        echo json_encode($smg, JSON_UNESCAPED_UNICODE);
        die();
    }





    public function editar(int $id)
    {
        $data = $this->model->editarCategoria($id);
        echo json_encode($data, JSON_UNESCAPED_UNICODE);
        die();
    }
    
    public function eliminar(int $id)
    {
        $data = $this->model->accionCategoria(0, $id);
        if ($data == 1) {
            $smg = "ok";
        } else {
            $smg = "error al eliminar el dni";
        }
        echo json_encode($smg, JSON_UNESCAPED_UNICODE);
        die();
    }

    public function reingresar(int $id)
    {
        $data = $this->model->accionCategoria(1, $id);
        if ($data == 1) {
            $smg = "ok";
        } else {
            $smg = "error al reingresar el dni";
        }
        echo json_encode($smg, JSON_UNESCAPED_UNICODE);
        die();
    }
    
    
    
    
 





















}
?>
